@@ -11,16 +11,14 @@
 #' @aliases blogdown-package
 #' @import utils
 #' @import stats
-#' @importFrom xfun attr in_dir read_utf8 write_utf8
+#' @importFrom xfun attr in_dir read_utf8 write_utf8 is_windows is_macos
+#'   file_exists dir_exists file_ext msg_cat dir_create del_empty_dir proc_kill
 #' @examples if (interactive()) blogdown::new_site()
 NULL
 
 with_ext = function(...) xfun::with_ext(...)
-dir_exists = bookdown:::dir_exists
-dir_create = bookdown:::dir_create
 existing_files = bookdown:::existing_files
 fetch_yaml = function(f) bookdown:::fetch_yaml(read_utf8(f))
-Rscript = xfun::Rscript
 
 `%n%` = knitr:::`%n%`
 
@@ -29,10 +27,18 @@ blogdown_skeleton = function(path, ...) {
   new_site(dir = path, ..., serve = FALSE)
 }
 
-# stop all servers when the package is unloaded or R session is ended
 .onLoad = function(libname, pkgname) {
+  # stop all servers when the package is unloaded or R session is ended
   reg.finalizer(asNamespace(pkgname), function(e) {
     opts$set(quitting = TRUE); on.exit(opts$set(quitting = NULL), add = TRUE)
     stop_server()
   }, onexit = TRUE)
+
+  # initialize some important global options, so RStudio could autocomplete
+  # options(); I can't set them to NULL directly because options(foo = NULL)
+  # would *remove* the option 'foo', so RStudio won't be able to recognize
+  # option names (I have to set them to I(NA) instead); I hate this ugly hack
+  if (interactive()) for (i in names(.options)) {
+    if (is.null(getOption(i))) options(.options[i])
+  }
 }
